# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-10-28 23:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('actstream', '0002_remove_action_data'),
    ]

    operations = [
        migrations.AddField(
            model_name='follow',
            name='flag',
            field=models.CharField(blank=True, db_index=True, default='', max_length=255),
        ),
        migrations.AlterUniqueTogether(
            name='follow',
            unique_together=set([('user', 'content_type', 'object_id', 'flag')]),
        ),
    ]
