try:
    from actstream.signals import action
except:
    pass

__version__ = '1.4.0'
__author__ = 'Asif Saif Uddin, Justin Quick <justquick@gmail.com>'
default_app_config = 'actstream.apps.ActstreamConfig'
